-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------
-- laver database skema hvis det ikke findes allerede og vlger tegnst
CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET utf8 ;
-- vlger at bruges mydb databasen
USE `mydb` ;

-- -----------------------------------------------------
-- Table `mydb`.`customers`
-- -----------------------------------------------------
-- laver tabel, som hedder customers hvis den ikke allerede findes
-- tabellen indeholder attributter med forskellige datatyper og lngden p datatyperne
-- AUTO_INCREMENT = tallet stiger automatisk op med 1 for hver gang
-- PRIMARY KEY, alts den unikke ngle til at identificere data i tabellen.
-- FOREIGN KEY = en ngle i en tabel, der peger p en primr ngle i en anden tabel
-- NOT NULL = attributtens felter m ikke vre tomme
-- Default NULL = attributtens felter null fra start af
-- UNIQUE INDEX = attributtens data m ikke vre ens
-- ENGINE = InnoDB. Srger for referentiel integritet.

CREATE TABLE IF NOT EXISTS `mydb`.`customers` (
  `idCustomers` INT(11) NOT NULL AUTO_INCREMENT,
  `Customer_firstname` VARCHAR(45) NOT NULL,
  `Customer_lastname` VARCHAR(45) NOT NULL,
  `Customer_phone` INT(11) NULL DEFAULT NULL,
  `Customer_mail` VARCHAR(45) NOT NULL,
  `Customer_birthday` DATE NULL DEFAULT NULL,
  `Customer_password` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`idCustomers`),
  UNIQUE INDEX `Customer_mail_UNIQUE` (`Customer_mail` ASC))
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`zipcodes`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`zipcodes` (
  `idZipcodes` INT(11) NOT NULL AUTO_INCREMENT,
  `city` VARCHAR(45) NULL DEFAULT NULL,
  PRIMARY KEY (`idZipcodes`),
  UNIQUE INDEX `idZipcodes_UNIQUE` (`idZipcodes` ASC))
ENGINE = InnoDB
AUTO_INCREMENT = 8211
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`address`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`address` (
  `idAddress` INT(11) NOT NULL AUTO_INCREMENT,
  `Firstaddress` VARCHAR(45) NOT NULL,
  `Secondaddress` VARCHAR(45) NULL DEFAULT NULL,
  `Customers_idCustomers` INT(11) NOT NULL,
  `Zipcodes_idZipcodes` INT(11) NOT NULL,
  PRIMARY KEY (`idAddress`, `Customers_idCustomers`, `Zipcodes_idZipcodes`),
  INDEX `fk_Address_Customers1_idx` (`Customers_idCustomers` ASC),
  INDEX `fk_Address_Zipcodes1_idx` (`Zipcodes_idZipcodes` ASC),
  CONSTRAINT `fk_Address_Customers1`
    FOREIGN KEY (`Customers_idCustomers`)
    REFERENCES `mydb`.`customers` (`idCustomers`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Address_Zipcodes1`
    FOREIGN KEY (`Zipcodes_idZipcodes`)
    REFERENCES `mydb`.`zipcodes` (`idZipcodes`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`orders`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`orders` (
  `Order_id` INT(11) NOT NULL AUTO_INCREMENT,
  `Order_date` DATE NULL DEFAULT NULL,
  `Status` INT(11) NOT NULL DEFAULT '0',
  `Customers_idCustomers` INT(11) NOT NULL,
  PRIMARY KEY (`Order_id`, `Customers_idCustomers`),
  UNIQUE INDEX `Order_id_UNIQUE` (`Order_id` ASC),
  INDEX `fk_Orders_Customers1_idx` (`Customers_idCustomers` ASC),
  CONSTRAINT `fk_Orders_Customers1`
    FOREIGN KEY (`Customers_idCustomers`)
    REFERENCES `mydb`.`customers` (`idCustomers`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`productcategories`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`productcategories` (
  `ProductCategories id` INT(11) NOT NULL AUTO_INCREMENT,
  `ProductCategoryName` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`ProductCategories id`),
  UNIQUE INDEX `ProductCategories id_UNIQUE` (`ProductCategories id` ASC))
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`products`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`products` (
  `Product_id` INT(11) NOT NULL AUTO_INCREMENT,
  `Product_name` VARCHAR(45) NULL DEFAULT NULL,
  `Product_info` TEXT(1000) NULL,
  `Product_price` INT(11) NULL DEFAULT NULL,
  `Product_image` VARCHAR(45) NULL DEFAULT NULL,
  `Product_location` INT(11) NULL DEFAULT NULL,
  `Product_minstock` INT(11) NULL DEFAULT NULL,
  `Product_qty` INT(11) NULL DEFAULT NULL,
  `ProductCategories_ProductCategories id` INT(11) NOT NULL,
  PRIMARY KEY (`Product_id`, `ProductCategories_ProductCategories id`),
  UNIQUE INDEX `Product_id_UNIQUE` (`Product_id` ASC),
  INDEX `fk_Products_ProductCategories1_idx` (`ProductCategories_ProductCategories id` ASC),
  CONSTRAINT `fk_Products_ProductCategories1`
    FOREIGN KEY (`ProductCategories_ProductCategories id`)
    REFERENCES `mydb`.`productcategories` (`ProductCategories id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
AUTO_INCREMENT = 6
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `mydb`.`orderline`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `mydb`.`orderline` (
  `Orders_Order_id` INT(11) NOT NULL,
  `Products_Product_id` INT(11) NOT NULL,
  `Order_qty` INT(11) NOT NULL,
  PRIMARY KEY (`Orders_Order_id`, `Products_Product_id`),
  INDEX `fk_Orders_has_Products_Products1_idx` (`Products_Product_id` ASC),
  INDEX `fk_Orders_has_Products_Orders1_idx` (`Orders_Order_id` ASC),
  CONSTRAINT `fk_Orders_has_Products_Orders1`
    FOREIGN KEY (`Orders_Order_id`)
    REFERENCES `mydb`.`orders` (`Order_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Orders_has_Products_Products1`
    FOREIGN KEY (`Products_Product_id`)
    REFERENCES `mydb`.`products` (`Product_id`)
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;








